Documentation
¶
Overview ¶
Package olists implements queries that operate on lists using the Twitter API v1.1.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FollowOpts ¶
type FollowOpts struct {
// Look up following by user ID rather than username.
ByID bool
// A pagination token provided by the server.
PageToken string
// The number of results to return per page (maximum 200).
// If zero, use the server default (20).
PerPage int
// Optional user fields to report with a successful update.
Optional types.UserFields
}
FollowOpts provides parameters for follower/following queries. A nil *FollowOpts provides zero values for all fields.
type ListOpts ¶
type ListOpts struct {
// A pagination token provided by the server.
PageToken string
// The number of results to return per page (maximum 200).
// If zero, use the server default (20).
PerPage int
// Optional user fields to report with a successful update.
Optional types.UserFields
}
ListOpts provides parameters for list queries. A nil *ListOpts provides zero values for all fields.
type Query ¶
Query is a query for list memberships.
func Followers ¶
func Followers(user string, opts *FollowOpts) Query
Followers constructs a query for the followers of a user.
API: 1.1/followers/list
func Following ¶
func Following(user string, opts *FollowOpts) Query
Following constructs a query for the "friends" of a user, which are those accounts the user is following.
API: 1.1/friends/list
func Subscribers ¶
Subscribers constructs a query for the subscribers to a list.
API: 1.1/lists/subscribers
func (Query) HasMorePages ¶
HasMorePages reports whether the query has more pages to fetch. This is true for a freshly-constructed query, and for an invoked query where the server not reported a next-page token.
func (Query) ResetPageToken ¶
func (q Query) ResetPageToken()
ResetPageToekn resets (clears) the query's current page token. Subsequently invoking the query will then fetch the first page of results.